==> pipewire-0.1.7-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/core_8h.js <==
var core_8h =
[
    [ "pw_core_events", "structpw__core__events.html", "structpw__core__events" ],
    [ "PW_CORE_PROP_DAEMON", "core_8h.html#acde5a7c70bacd6b33b2ec1993ac8ac84", null ],
    [ "PW_CORE_PROP_NAME", "core_8h.html#a3cdbdb005bf8606fadcf004d372f5c92", null ],
    [ "PW_CORE_PROP_VERSION", "core_8h.html#a1929dd6305b17ae7dba21c4f20e00a43", null ],
    [ "PW_PERM_IS_R", "core_8h.html#a2668b1c9a4b1e4b68fefe81e55d1ee59", null ],
    [ "PW_PERM_IS_W", "core_8h.html#aa61804de7cf6003defd8b26ef488ce56", null ],
    [ "PW_PERM_IS_X", "core_8h.html#a5dca3f2e9a9b71cc78525893eb80355b", null ],
    [ "PW_PERM_R", "core_8h.html#a2a31ac243ad99915377319b663daf426", null ],
    [ "PW_PERM_RWX", "core_8h.html#a77df16320c3bb338666f55b2b21e6e47", null ],
    [ "PW_PERM_W", "core_8h.html#a97d33a5e044ee126fd9991b8c70424aa", null ],
    [ "PW_PERM_X", "core_8h.html#a277828556118843e682c652bb1dc9c8e", null ],
    [ "PW_VERSION_CORE_EVENTS", "core_8h.html#aecb5def77dc04e427fda3af43fe56646", null ],
    [ "pw_permission_func_t", "core_8h.html#ab9ade78740c67c500a687682732ea05c", null ],
    [ "pw_core_add_listener", "core_8h.html#aaadab34920b5de0fd1ece5968a0f01b5", null ],
    [ "pw_core_destroy", "core_8h.html#a6e476d47973e8c20e816e58249f1aaec", null ],
    [ "pw_core_find_factory", "core_8h.html#a0e13266e34dceef21d7cbe3fcbb1d854", null ],
    [ "pw_core_find_global", "core_8h.html#a2fb1ec794839834c891c627441502e3e", null ],
    [ "pw_core_for_each_global", "core_8h.html#af61f57b3be80dd1b3a9b657c89991bd6", null ],
    [ "pw_core_get_global", "core_8h.html#a7b70cabc1099c945b082d155adff30be", null ],
    [ "pw_core_get_info", "core_8h.html#a32c26764e61f815962fa05f5f82ed7d0", null ],
    [ "pw_core_get_main_loop", "core_8h.html#a7f93de0a13b103b66b3c283151acd511", null ],
    [ "pw_core_get_properties", "core_8h.html#ac1fcf434e5d5080943c15fc07fa29a99", null ],
    [ "pw_core_get_support", "core_8h.html#a8833ae17b3e39130b3f9c5efe799d057", null ],
    [ "pw_core_get_type", "core_8h.html#a867782ce1c528406a720c2b6357f8626", null ],
    [ "pw_core_new", "core_8h.html#a49b9c1175b1db89a6bcb08c2ae184a5d", null ],
    [ "pw_core_set_permission_callback", "core_8h.html#ae8a7d5be107082a82ccd1fdba6bd56dd", null ],
    [ "pw_core_update_properties", "core_8h.html#a2415b0210c64cce866c832006e6fadec", null ]
];

==> pipewire-0.1.9-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/core_8h.js <==
var core_8h =
[
    [ "pw_core_events", "structpw__core__events.html", "structpw__core__events" ],
    [ "PW_CORE_PROP_DAEMON", "core_8h.html#acde5a7c70bacd6b33b2ec1993ac8ac84", null ],
    [ "PW_CORE_PROP_HOST_NAME", "core_8h.html#a1c440dde895eff9f3fd65b76d9b69369", null ],
    [ "PW_CORE_PROP_NAME", "core_8h.html#a3cdbdb005bf8606fadcf004d372f5c92", null ],
    [ "PW_CORE_PROP_USER_NAME", "core_8h.html#a20f21fd17f0428fe9f4536dcb656e7d5", null ],
    [ "PW_CORE_PROP_VERSION", "core_8h.html#a1929dd6305b17ae7dba21c4f20e00a43", null ],
    [ "PW_PERM_IS_R", "core_8h.html#a2668b1c9a4b1e4b68fefe81e55d1ee59", null ],
    [ "PW_PERM_IS_W", "core_8h.html#aa61804de7cf6003defd8b26ef488ce56", null ],
    [ "PW_PERM_IS_X", "core_8h.html#a5dca3f2e9a9b71cc78525893eb80355b", null ],
    [ "PW_PERM_R", "core_8h.html#a2a31ac243ad99915377319b663daf426", null ],
    [ "PW_PERM_RWX", "core_8h.html#a77df16320c3bb338666f55b2b21e6e47", null ],
    [ "PW_PERM_W", "core_8h.html#a97d33a5e044ee126fd9991b8c70424aa", null ],
    [ "PW_PERM_X", "core_8h.html#a277828556118843e682c652bb1dc9c8e", null ],
    [ "PW_VERSION_CORE_EVENTS", "core_8h.html#aecb5def77dc04e427fda3af43fe56646", null ],
    [ "pw_core_add_listener", "core_8h.html#aaadab34920b5de0fd1ece5968a0f01b5", null ],
    [ "pw_core_destroy", "core_8h.html#a6e476d47973e8c20e816e58249f1aaec", null ],
    [ "pw_core_find_factory", "core_8h.html#a0e13266e34dceef21d7cbe3fcbb1d854", null ],
    [ "pw_core_find_global", "core_8h.html#a2fb1ec794839834c891c627441502e3e", null ],
    [ "pw_core_for_each_global", "core_8h.html#aa2cd9bb4187f992108f8110143262968", null ],
    [ "pw_core_get_global", "core_8h.html#a7b70cabc1099c945b082d155adff30be", null ],
    [ "pw_core_get_info", "core_8h.html#a32c26764e61f815962fa05f5f82ed7d0", null ],
    [ "pw_core_get_main_loop", "core_8h.html#a7f93de0a13b103b66b3c283151acd511", null ],
    [ "pw_core_get_properties", "core_8h.html#ac1fcf434e5d5080943c15fc07fa29a99", null ],
    [ "pw_core_get_support", "core_8h.html#a8833ae17b3e39130b3f9c5efe799d057", null ],
    [ "pw_core_get_type", "core_8h.html#a867782ce1c528406a720c2b6357f8626", null ],
    [ "pw_core_new", "core_8h.html#a49b9c1175b1db89a6bcb08c2ae184a5d", null ],
    [ "pw_core_update_properties", "core_8h.html#a9918e38cb727fa7b8d59cca7b318f3c7", null ]
];
